==> jft-0.0.128.tar.gz: jft-0.0.128/jft/directory/list_testables.py <==
from jft.directory.list_pyfilepaths import f as list_py_files
from jft.directory.make import f as mkdir
from jft.file.save import f as save
from os import remove
from jft.directory.remove import f as remove_dir
from os.path import exists

_f = lambda root='.': [
  φ for φ in list_py_files(root, [])
  if not any([
    φ in [
      './scrap.py',
      './patch.py',
      './test.py',
      './setup.py',
      './temp.py',
      './temp/foo.py',
      './temp/jft.args.py',
      './temp/jft.start.py',
      './temp/jft.app.py',
      './temp/jft.no_comment_present.py',
      './temp/jft.has_comment_to_be_deleted.py',
      './temp/jft.has_comment_to_not_be_deleted.py',
      './fake_setup.py',
      './_π_test_failed/_expected_fail.py',
      './_π_test_failed/_expected_pass.py',
      './package_list.py',
      './jft/test/do.py'
    ],
    φ.endswith('__init__.py'),
    φ.endswith('data.py')
  ])
]

def f(root='.'):
  Π = _f(root)
  Π = [π for π in Π if 'excludables' not in π]
  
  for excludable_directory in ['./archive/', './test_data/']:
    Π = [π for π in Π if excludable_directory not in π]
  
  if exists('excludables.py'):
    from excludables import excludables as Π_x
    for π_x in Π_x:
      Π = [π for π in Π if π_x not in π]
  
  return Π

temp_dir_0 = './_'
temp_dir_1 = './_/_'
temp_files_and_content = [
  (f'{temp_dir_0}/foo.py', 'f = lambda: None\nt = lambda: True'),
  (f'{temp_dir_0}/xyz.txt', 'xyz'),
  (f'{temp_dir_1}/abc.txt', 'abc'),
  (f'{temp_dir_1}/bar.py', 'f = lambda: None\nt = lambda: True'),
]

def setup():
  [mkdir(temp_dir) for temp_dir in [temp_dir_0, temp_dir_1]]
  [save(filename, content) for (filename, content) in temp_files_and_content]

def tear_down():
  [remove(filename) for (filename, _) in temp_files_and_content]
  remove_dir(temp_dir_1)
  remove_dir(temp_dir_0)

def t():
  setup()
  expectation = set([
    './_/_/bar.py',
    './_/foo.py'
  ])
  observation = set(f(temp_dir_0))
  test_result = expectation == observation
  tear_down()

  if not test_result:
    print(f'expectation: {expectation}')
    print(f'observation: {observation}')

  return test_result

==> jft-0.0.145.tar.gz: jft-0.0.145/jft/directory/list_testables.py <==
from jft.directory.list_pyfilepaths import f as list_py_files
from jft.directory.make import f as mkdir
from jft.file.save import f as save
from os import remove
from jft.directory.remove import f as remove_dir
from os.path import exists

_f = lambda root='.': [
  φ for φ in list_py_files(root, [])
  if not any([
    φ in [
      './scrap.py',
      './patch.py',
      './test.py',
      './setup.py',
      './temp.py',
      './temp/foo.py',
      './temp/jft.args.py',
      './temp/jft.start.py',
      './temp/jft.app.py',
      './temp/jft.no_comment_present.py',
      './temp/jft.has_comment_to_be_deleted.py',
      './temp/jft.has_comment_to_not_be_deleted.py',
      './fake_setup.py',
      './_pi_test_failed/_expected_fail.py',
      './_pi_test_failed/_expected_pass.py',
      './package_list.py',
      './jft/test/do.py'
    ],
    φ.endswith('__init__.py'),
    φ.endswith('data.py')
  ])
]

def f(root='.'):
  _Pi = _f(root)
  _Pi = [_pi for _pi in _Pi if 'excludables' not in _pi]
  
  for excludable_directory in ['./archive/', './test_data/']:
    _Pi = [_pi for _pi in _Pi if excludable_directory not in _pi]
  
  if exists('excludables.py'):
    from excludables import excludables as _Pi_x
    for _pi_x in _Pi_x:
      _Pi = [_pi for _pi in _Pi if _pi_x not in _pi]
  
  return _Pi

temp_dir_0 = './_'
temp_dir_1 = './_/_'
temp_files_and_content = [
  (f'{temp_dir_0}/foo.py', 'f = lambda: None\nt = lambda: True'),
  (f'{temp_dir_0}/xyz.txt', 'xyz'),
  (f'{temp_dir_1}/abc.txt', 'abc'),
  (f'{temp_dir_1}/bar.py', 'f = lambda: None\nt = lambda: True'),
]

def setup():
  [mkdir(temp_dir) for temp_dir in [temp_dir_0, temp_dir_1]]
  [save(filename, content) for (filename, content) in temp_files_and_content]

def tear_down():
  [remove(filename) for (filename, _) in temp_files_and_content]
  remove_dir(temp_dir_1)
  remove_dir(temp_dir_0)

def t():
  setup()
  expectation = set([
    './_/_/bar.py',
    './_/foo.py'
  ])
  observation = set(f(temp_dir_0))
  test_result = expectation == observation
  tear_down()

  if not test_result:
    print(f'expectation: {expectation}')
    print(f'observation: {observation}')

  return test_result
